==> kadu_3.0.orig.tar.bz2: kadu-3.0/plugins/antistring/translations/antistring_es_MX.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es_MX" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Conversación</translation>
    </message>
    <message>
        <source>Antistring</source>
        <translation>Prevención de cadenas de mensaje</translation>
    </message>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>Enable Antistring</source>
        <translation>Habilitar prevención de cadenas de mensaje</translation>
    </message>
    <message>
        <source>Block message</source>
        <translation>Mensaje de bloqueo</translation>
    </message>
    <message>
        <source>Admonition</source>
        <translation>Amonestación</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Registro</translation>
    </message>
    <message>
        <source>Write log to file</source>
        <translation>Escribir registro en el archivo</translation>
    </message>
    <message>
        <source>Conditions</source>
        <translation>Condiciones</translation>
    </message>
    <message>
        <source>Antistring notifications</source>
        <translation>Notificaciones de prevención de cadenas de mensajes</translation>
    </message>
</context>
<context>
    <name>Antistring</name>
    <message>
        <source>     DATA AND TIME      ::   ID   ::    MESSAGE
</source>
        <translation>     DATOS Y TIEMPO      ::   ID   ::    MENSAJE
</translation>
    </message>
</context>
<context>
    <name>AntistringConfigurationUiHandler</name>
    <message>
        <source>Condition</source>
        <translation>Condición</translation>
    </message>
    <message>
        <source>Don&apos;t use</source>
        <translation>No usar</translation>
    </message>
    <message>
        <source>Factor</source>
        <translation>Factor</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Agregar</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Cambiar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
</context>
<context>
    <name>AntistringNotification</name>
    <message>
        <source>Antistring</source>
        <translation>Prevención de cadenas de mensaje</translation>
    </message>
    <message>
        <source>Your interlocutor send you love letter</source>
        <translation>Su interlocutor le envía una carta de amor</translation>
    </message>
</context>
</TS>

==> kadu_4.1.orig.tar.bz2: kadu-4.1/plugins/antistring/translations/antistring_es_MX.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es_MX" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Conversación</translation>
    </message>
    <message>
        <source>Antistring</source>
        <translation>Prevención de cadenas de mensaje</translation>
    </message>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>Enable Antistring</source>
        <translation>Habilitar prevención de cadenas de mensaje</translation>
    </message>
    <message>
        <source>Block message</source>
        <translation>Mensaje de bloqueo</translation>
    </message>
    <message>
        <source>Admonition</source>
        <translation>Amonestación</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Registro</translation>
    </message>
    <message>
        <source>Write log to file</source>
        <translation>Escribir registro en el archivo</translation>
    </message>
    <message>
        <source>Conditions</source>
        <translation>Condiciones</translation>
    </message>
    <message>
        <source>Antistring notifications</source>
        <translation>Notificaciones de prevención de cadenas de mensajes</translation>
    </message>
</context>
<context>
    <name>AntistringConfigurationUiHandler</name>
    <message>
        <source>Condition</source>
        <translation>Condición</translation>
    </message>
    <message>
        <source>Don&apos;t use</source>
        <translation>No usar</translation>
    </message>
    <message>
        <source>Factor</source>
        <translation>Factor</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Agregar</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Cambiar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
</context>
<context>
    <name>AntistringMessageFilter</name>
    <message>
        <source>     DATA AND TIME      ::   ID   ::    MESSAGE
</source>
        <translation>     DATOS Y TIEMPO      ::   ID   ::    MENSAJE
</translation>
    </message>
</context>
<context>
    <name>AntistringNotificationService</name>
    <message>
        <source>Antistring</source>
        <translation>Prevención de cadenas de mensaje</translation>
    </message>
    <message>
        <source>Your interlocutor send you love letter</source>
        <translation>Su interlocutor le envía una carta de amor</translation>
    </message>
</context>
</TS>
